Module linear

Module linear 

For quantizing values linearly to a range.

Traits

Linear
For quantizing values linearly to a range.

Functions

dequantize
Linearly dequantize a value.
max_error
The maximum error when quantizing linearly. The absolute difference between the quantized and original value will not be greater than this, unless it has been clamped because it was out of range.
quantize
Linearly quantize a value.